@@ -1,4 +1,5 @@
 import pytest
+import copy
 
 def test_rivierapro():
     import os
@@ -15,8 +16,8 @@ def test_rivierapro():
     }
 
     #FIXME: Add VPI tests
-    (backend, args, work_root) = setup_backend(paramtypes, name, tool, tool_options, use_vpi=False)
-    backend.configure(args)
+    (backend, work_root) = setup_backend(paramtypes, name, tool, tool_options, use_vpi=False)
+    backend.configure()
 
     compare_files(ref_dir, work_root, [
         'edalize_build_rtl.tcl',
@@ -24,7 +25,7 @@ def test_rivierapro():
         'edalize_main.tcl',
     ])
 
-    orig_env = os.environ.copy()
+    orig_env = copy.deepcopy(os.environ)
     os.environ['ALDEC_PATH'] = os.path.join(tests_dir, 'mock_commands')
 
     backend.build()
@@ -32,7 +33,7 @@ def test_rivierapro():
 
     compare_files(ref_dir, work_root, ['vsim.cmd'])
 
-    backend.run(args)
+    backend.run()
 
     with open(os.path.join(ref_dir, 'vsim2.cmd')) as fref, open(os.path.join(work_root, 'vsim.cmd')) as fgen:
         assert fref.read() == fgen.read()
