@@ -1,25 +1,21 @@
-import pytest
-
 def test_xsim():
     import os
-    import shutil
     from edalize_common import compare_files, setup_backend, tests_dir
 
     ref_dir      = os.path.join(tests_dir, __name__)
-    paramtypes   = ['plusarg', 'vlogdefine', 'vlogparam']
+    paramtypes   = ['plusarg', 'vlogdefine', 'vlogparam', 'generic']
     name         = 'test_xsim_0'
     tool         = 'xsim'
     tool_options = {'xelab_options' : ['some', 'xelab_options'],
                     'xsim_options'  : ['a', 'few', 'xsim_options']}
 
-    (backend, args, work_root) = setup_backend(paramtypes, name, tool, tool_options)
-    backend.configure(args)
+    (backend, work_root) = setup_backend(paramtypes, name, tool, tool_options)
+    backend.configure()
 
     compare_files(ref_dir, work_root, ['config.mk',
                                        'Makefile',
                                        name+'.prj',
-                                       'run-gui.tcl',
-                                       'run.tcl'])
+    ])
 
     backend.build()
     compare_files(ref_dir, work_root, ['xelab.cmd'])
@@ -28,6 +24,6 @@ def test_xsim():
     os.makedirs(xsimkdir)
     with open(os.path.join(xsimkdir, 'xsimk'), 'w') as f:
         f.write("I am a compiled simulation kernel\n")
-    backend.run(args)
+    backend.run()
 
     compare_files(ref_dir, work_root, ['xsim.cmd'])
